@@ -5,7 +5,7 @@ use crate::pdu::formats::WriteStream;
 use crate::pdu::PduParseError;
 
 #[derive(Debug, PartialEq)]
-pub struct BindTransceiverRespPdu(BindRespData);
+pub struct BindTransceiverRespPdu(pub BindRespData);
 
 impl BindTransceiverRespPdu {
     pub fn new(system_id: &str) -> Result<Self, PduParseError> {
